﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Ninject;

namespace IndustryConnect.Bootcamp.Four
{
    class Program
    {
        static StandardKernel _kernel;

        static void Main(string[] args)
        {
            Setup();

            var jobService = _kernel.Get<IJobService>();

            var oneJobSeeker = new JobSeeker
            {
                Name = "Mike",
                Description = "Just graduated",
                ExperienceLevel = 0
            };

            if (!jobService.ApplyJob(oneJobSeeker))
            {
                Console.WriteLine("After the program, {0} keeps applying for jobs", oneJobSeeker.Name);
                jobService.ApplyJob(oneJobSeeker);
            }

            Console.ReadKey();

            // Production use cases will be explained during session
        }

        static void Setup()
        {
            _kernel = new StandardKernel();

            // Tells Ninject to use JobService class to create instance for IJobService
            // and only one instance should be created in this application.          
            _kernel.Bind<IJobService>().To<JobService>().InSingletonScope();

            // use JobReadyProgram class to create instance for IJobReadyProgram.
            // and only one instance should be created in this application.

            // If you see the constructor of JobService above, it also requires IJobReadyProgram as parameter.
            // Since we have bound it here, the parameter will automatically populated since we had binding below.
            _kernel.Bind<IJobReadyProgram>().To<JobReadyProgram>().InSingletonScope();
        }
    }
}
